Ory.Model.ContinueWithRedirectBrowserTo
(ory_client v1.22.37)
Indicates, that the UI flow could be continued by showing a recovery ui
Indicates, that the UI flow could be continued by showing a recovery ui