Ory.Model.LoginFlowState
(ory_client v1.22.26)
The experimental state represents the state of a login flow. This field is EXPERIMENTAL and subject to change!
The experimental state represents the state of a login flow. This field is EXPERIMENTAL and subject to change!