Ory. Api. Elements
(ory_client v1.22.57)
API calls for all endpoints tagged Elements.
Summary
Functions
Get Ory Elements configuration Returns a subset of the project's configuration for the given host. The response only contains non-sensitive data that is used to customize the behavior of Ory Elements.
Functions
@spec get_configuration( Tesla.Env.client(), keyword() ) :: {:ok, Ory.Model.GenericError.t()} | {:ok, Ory.Model.ElementsConfiguration.t()} | {:error, Tesla.Env.t()}
Get Ory Elements configuration Returns a subset of the project's configuration for the given host. The response only contains non-sensitive data that is used to customize the behavior of Ory Elements.
Parameters
connection(Ory.Connection): Connection to serveropts(keyword): Optional parameters
Returns
{:ok, Ory.Model.ElementsConfiguration.t}on success{:error, Tesla.Env.t}on failure